starcluster.exception.IncompatibleCluster

Package starcluster :: Module exception :: Class IncompatibleCluster |
[hide private]
[frames] | no frames]

# Class IncompatibleCluster

source code

Instance Methods | [hide private]
__init__(self, group) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `BaseException`: `__str__`, `explain` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| main_msg = ``'``The cluster \'%(tag)s\' was either created by a pr``...``
| insts_msg = ``'``The cluster \'%(tag)s\' currently has %(num_nodes``...``
| no_insts_msg = ``'``The cluster \'%(tag)s\' does not have any node``...``
| terminate_msg = ``'``Please terminate the cluster using:\n\n $` `...``

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, group) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### main_msg Value:
      '''The cluster \'%(tag)s\' was either created by a previous stable or
      development version of StarCluster or you manually created the \'%(gro
      up)s\' group. In any case \'%(tag)s\' cannot be used with this version
       of StarCluster (%(version)s).

      '''

  ### insts_msg Value:
      '''The cluster \'%(tag)s\' currently has %(num_nodes)d active nodes.

      '''

  ### no_insts_msg Value:
      '''The cluster \'%(tag)s\' does not have any nodes and is safe to term
      inate.

      '''

  ### terminate_msg Value:
      '''Please terminate the cluster using:

          $ starcluster terminate %(tag)s
      '''